==> moodle_1.3.1.orig.tar.gz: moodle/lang/pl/auth.php <==
<?PHP // $Id: auth.php,v 1.9 2004/02/12 22:17:44 adamtpaw Exp $ 
      // auth.php - created with Moodle 1.2 development (2004020300)


$string['auth_dbdescription'] = 'Metoda ta wykorzystuje tabel zewntrznej bazy danych dla sprawdzenia czy podana nazwa uytkownika i haso s poprawne. W przypadku nowego konta, informacje z innych pl rwnie mog zosta skopiowane do Moodle.';
$string['auth_dbextrafields'] = 'Te pola s opcjonalne. Moesz wstpnie wypeni niektre pola dotyczce uytkownika informacj z <B>pl zewntrznej bazy danych</B>, ktre tutaj okrelasz. <P>Jeeli nic  w tym miejscu nie wpiszesz, uyte zostan wartoci domylne. <P> W obu przypadkach, uytkownik bdzie mg dokona edycji tych pl po zalogowaniu';
$string['auth_dbfieldpass'] = 'Nazwa pola zawierajcego hasa';
$string['auth_dbfielduser'] = 'Nazwa pola zawierajcego nazwy uytkownikw';
$string['auth_dbhost'] = 'Komputer bdcy hostem serwera bazy danych.';
$string['auth_dbname'] = 'Nazwa bazy danych';
$string['auth_dbpass'] = 'Haso dla powyszej nazwy uytkownika';
$string['auth_dbpasstype'] = 'Okrel format stosowany przez pole hasa. Kodowanie MD5 przydatne jest przy czeniu si z innymi popularnymi aplikacjami sieci WWW, takimi jak PostNuke';
$string['auth_dbtable'] = 'Nazwa tabeli w bazie danych';
$string['auth_dbtitle'] = 'Korzystaj z zewntrznej bazy danych';
$string['auth_dbtype'] = 'Rodzaj bazy danych (szczegowe informacje: <A HREF=../lib/adodb/readme.htm#drivers>ADOdb documentation</A>';
$string['auth_dbuser'] = 'Nazwa uytkownika majcego prawo dostpu do odczytu z bazy';
$string['auth_emaildescription'] = 'Potwierdzenie e-mailem jest domyln metod uwierzytelniania. Uytkownik rejestruje si wybierajc wasn, now nazw uytkownika oraz haso, a nastpnie wysyane jest potwierdzenie na adres jego konta pocztowego. E-mail ten zawiera bezpieczny odnonik do strony, na ktrej uytkownik moe potwierdzi zarejestrowanie swojego konta. Przy kolejnych logowaniach dokonywane jest tylko porwnanie nazwy uytkownika i hasa z wartociami zapisanymi w bazie danych Moodle.';
$string['auth_emailtitle'] = 'Uwierzytelnienie z wykorzystaniem poczty elektronicznej';
$string['auth_imapdescription'] = 'Metoda ta korzysta z serwera IMAP w celu sprawdzenia czy podana nazwa uytkownika i haso s poprawne.';
$string['auth_imaphost'] = 'Adres serwera IMAP. Naley stosowa adres IP, a nie nazw DNS.';
$string['auth_imapport'] = 'Numer portu serwera IMAP, zwykle 142 lub 993.';
$string['auth_imaptitle'] = 'Uyj serwera IMAP';
$string['auth_imaptype'] = 'Typ serwera IMAP. Serwery IMAP mog stosowa rne rodzaje uwierzytelniania i negocjacji.';
$string['auth_ldap_bind_dn'] = 'Okrel tutaj czy chcesz skorzysta z funkcji bind-user do szukania uytkownikw, np. \'cn=ldapuser,ou=public,o=org\'';
$string['auth_ldap_bind_pw'] = 'Haso dla funkcji bind-user';
$string['auth_ldap_contexts'] = 'Lista kontekstw, w ktrych znajduj si uytkownicy. Oddzielaj rne konteksty symbolem \';\', np. \'ou=users,o=org; ou=others,o=org\'';
$string['auth_ldap_create_context'] = 'Jeeli wczysz opcj tworzenia uytkownikw z potwierdzeniem poczt elektroniczn, zdefiniuj kontekst, w ktrym tworzeni s tacy uytkownicy. Powinien by rni si od kontekstu innych uytkownikw w celu uniknicia problemw zwizanych z bezpieczestwem. Nie musisz dodawa tego kontekstu do zmiennej ldap_context-variable - Moodle automatycznie wyszuka uytkownikw w tym kontekcie.';
$string['auth_ldap_creators'] = 'Lista grup, ktrych czonkowie mog tworzy nowe kursy. Oddziel kolejne grupy symbolem \';\'. Przykadowa lista: \'cn=teachers,ou=staff,o=myorg\'';
$string['auth_ldap_host_url'] = 'Okrel hosta LDAP za pomoc adresu, np. URL\'ldap://ldap.myorg.com/\' lub \'ldaps://ldap.myorg.com/\'';
$string['auth_ldap_memberattribute'] = 'Okrel atrybut czonkostwa uytkownika jeeli uytkownik naley do grupy. Zazwyczaj jest to \'member\'';
$string['auth_ldap_search_sub'] = 'Wpisz warto &lt;&gt; 0 jeeli chcesz szuka uytkownikw z podkontekstw';
$string['auth_ldap_update_userinfo'] = 'Uaktualnij informacje o uytkowniku (imi, nazwisko, adres...) z LDAP do Moodle. Informacje na temat mapowania: /auth/ldap/attr_mappings.php';
$string['auth_ldap_user_attribute'] = 'Atrybut uywany do nazywania/szukania uytkownikw, zwykle \'cn\'.';
$string['auth_ldapdescription'] = 'Metoda ta zapewnia uwierzytelnienie wzgldem zewntrznego serwera LDAP.<br> Jeeli podana nazwa uytkownika i haso s poprawne, Moodle dokonuje wpisu nowego uytkownika do swojej bazy danych. Modu ten moe odczytywa atrybuty uytkownika z LDAP i wstpnie wypeni odpowiednie pola w Moodle. Przy kolejnych logowaniach sprawdzane s tylko nazwa uytkownika i haso.';
$string['auth_ldapextrafields'] = 'Te pola s opcjonalne. Moesz wstpnie wypeni niektre pola dotyczce uytkownikw Moodle informacjami z okrelonych tutaj <B>pl LDAP.<B> <P> Jeeli pola te pozostawisz puste, adne informacje nie zostan przeniesione z LDAP i wykorzystane zostan wartoci domylne Moodle. <P> W obu przypadkach, uytkownik bdzie mg dokona edycji tych pl po zalogowaniu.';
$string['auth_ldaptitle'] = 'Uyj serwera LDAP';
$string['auth_manualdescription'] = 'Metoda ta uniemoliwia uytkownikom tworzenie wasnych kont. Wszystkie konta musz by rcznie utworzone przez administratora (Admin User).';
$string['auth_manualtitle'] = 'Tylko konta utworzone rcznie';
$string['auth_multiplehosts'] = 'Mona wskaza wicej komputerw-hostw np. host1.com; host2.com; host3.com';
$string['auth_nntpdescription'] = 'Metoda ta wykorzystuje serwer NNTP w celu sprawdzenia czy podana nazwa uytkownika i haso s poprawne.';
$string['auth_nntphost'] = 'Adres serwera NNTP. Naley stosowa adres IP, a nie nazw DNS.';
$string['auth_nntpport'] = 'Port serwera (najczciej 119)';
$string['auth_nntptitle'] = 'Uyj serwera NNTP';
$string['auth_nonedescription'] = 'Uytkownicy mog si zarejestrowa i niezwocznie utworzy dziaajce konta, bez uwierzytelniania wzgldem zewntrznego serwera i potwierdzenia e-mailem. Korzystaj z tej opcji ostronie pamitajc o moliwych problemach z bezpieczestwem i administracj.';
$string['auth_nonetitle'] = 'Brak uwierzytelniania';
$string['auth_pop3description'] = 'Metoda ta wykorzystuje serwer POP3 w celu sprawdzenia czy podana nazwa uytkownika i haso s poprawne.';
$string['auth_pop3host'] = 'Adres serwera POP3. Naley stosowa adres IP, a nie nazw DNS.';
$string['auth_pop3port'] = 'Port serwera (najczciej 110)';
$string['auth_pop3title'] = 'Uyj serwera POP3';
$string['auth_pop3type'] = 'Typ serwera. Jeeli Twj serwer wykorzystuje certyfikaty bezpieczestwa, wybierz pop3cert.';
$string['auth_user_create'] = 'Wcz opcj tworzenia uytkownikw';
$string['auth_user_creation'] = 'Nowi (anonimowi) uytkownicy mog tworzy konta uytkownika uywajc zewntrznego rda uwierzytelniania z potwierdzeniem poczt elektroniczn. Jeeli wczysz t opcj, pamitaj rwnie o skonfigurowaniu zwizanych z moduami opcji tworzenia uytkownikw.';
$string['auth_usernameexists'] = 'Wybrana nazwa uytkownika ju istnieje - prosz wybra inn.';
$string['authenticationoptions'] = 'Opcje uwierzytelniania';
$string['authinstructions'] = 'Moesz tutaj wprowadzi instrukcje dla Twoich uytkownikw dotyczce nazwy uytkownika i hasa, ktrych powinni uywa. Tekst wpisany w tym miejscu pojawi si na stronie logowania. Jeeli nic nie wpiszesz, nie zostan wywietlone adne instrukcje.';
$string['changepassword'] = 'Zmie adres URL hasa';
$string['changepasswordhelp'] = 'Moesz tutaj okreli miejsce, w ktrym Twoi uytkownicy mog odzyska lub zmieni swoja nazw uytkownika/haso, jeeli ich zapomn. Wybranie tej opcji spowoduje wywietlenie przycisku na stronie logowania i stronach uytkownika. Jeeli nic nie wpiszesz, przycisk nie zostanie wywietlony.';
$string['chooseauthmethod'] = 'Wybierz sposb uwierzytelniania';
$string['guestloginbutton'] = 'Przycisk logowania jako go';
$string['instructions'] = 'Instrukcje';
$string['md5'] = 'Kodowanie MD5';
$string['plaintext'] = 'Zwyky tekst';
$string['showguestlogin'] = 'Moesz ukry bd pokaza przycisk logowania jako go';

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/pl/auth.php <==
<?PHP // $Id$ 
      // auth.php - created with Moodle 1.4 (2004083100)


$string['auth_dbdescription'] = 'Metoda ta wykorzystuje tabel zewntrznej bazy danych dla sprawdzenia czy podana nazwa uytkownika i haso s poprawne. W przypadku nowego konta, informacje z innych pl rwnie mog zosta skopiowane do Moodle.';
$string['auth_dbextrafields'] = 'Te pola s opcjonalne. Moesz wstpnie wypeni niektre pola dotyczce uytkownika informacj z <B>pl zewntrznej bazy danych</B>, ktre tutaj okrelasz. <P>Jeeli nic w tym miejscu nie wpiszesz, uyte zostan wartoci domylne. <P> W obu przypadkach, uytkownik bdzie mg dokona edycji tych pl po zalogowaniu';
$string['auth_dbfieldpass'] = 'Nazwa pola zawierajcego hasa';
$string['auth_dbfielduser'] = 'Nazwa pola zawierajcego nazwy uytkownikw';
$string['auth_dbhost'] = 'Komputer bdcy hostem serwera bazy danych.';
$string['auth_dbname'] = 'Nazwa bazy danych';
$string['auth_dbpass'] = 'Haso dla powyszej nazwy uytkownika';
$string['auth_dbpasstype'] = 'Okrel format stosowany przez pole hasa. Kodowanie MD5 przydatne jest przy czeniu si z innymi popularnymi aplikacjami sieci WWW, takimi jak PostNuke';
$string['auth_dbtable'] = 'Nazwa tabeli w bazie danych';
$string['auth_dbtitle'] = 'Korzystaj z zewntrznej bazy danych';
$string['auth_dbtype'] = 'Rodzaj bazy danych (szczegowe informacje: <A HREF=../lib/adodb/readme.htm#drivers>ADOdb documentation</A>';
$string['auth_dbuser'] = 'Nazwa uytkownika majcego prawo dostpu do odczytu z bazy';
$string['auth_emaildescription'] = 'Potwierdzenie e-mailem jest domyln metod uwierzytelniania. Uytkownik rejestruje si wybierajc wasn, now nazw uytkownika oraz haso, a nastpnie wysyane jest potwierdzenie na adres jego konta pocztowego. E-mail ten zawiera bezpieczny odnonik do strony, na ktrej uytkownik moe potwierdzi zarejestrowanie swojego konta. Przy kolejnych logowaniach dokonywane jest tylko porwnanie nazwy uytkownika i hasa z wartociami zapisanymi w bazie danych Moodle.';
$string['auth_emailtitle'] = 'Uwierzytelnienie z wykorzystaniem poczty elektronicznej';
$string['auth_fccreators'] = 'Lista grup, ktrych czonkowie s upowanieni do tworzenia nowych kursw. Oddziel kolejne grupy za pomoc rednika \';\'. Nazwy musz by identyczne jak na serwerze FirstClass. Wielko liter ma znaczenie.';
$string['auth_fcdescription'] = 'Ta metoda uywa serwera FirstClass aby sprawdzi czy podana nazwa uytkownika i haso s poprawne.';
$string['auth_fcfppport'] = 'Port serwera (zwykle jest to 3333)';
$string['auth_fchost'] = 'Adres serwera FirstClass. Wpisz adres IP lub nazw DNS.';
$string['auth_fcpasswd'] = 'Haso do powyszgo konta.';
$string['auth_fctitle'] = 'Uywaj serwera FirstClass';
$string['auth_fcuserid'] = 'ID uytkownika dla konta FirstClass z prawami Subadministratora.';
$string['auth_imapdescription'] = 'Metoda ta korzysta z serwera IMAP w celu sprawdzenia czy podana nazwa uytkownika i haso s poprawne.';
$string['auth_imaphost'] = 'Adres serwera IMAP. Naley stosowa adres IP, a nie nazw DNS.';
$string['auth_imapport'] = 'Numer portu serwera IMAP, zwykle 142 lub 993.';
$string['auth_imaptitle'] = 'Uyj serwera IMAP';
$string['auth_imaptype'] = 'Typ serwera IMAP. Serwery IMAP mog stosowa rne rodzaje uwierzytelniania i negocjacji.';
$string['auth_ldap_bind_dn'] = 'Okrel tutaj czy chcesz skorzysta z funkcji bind-user do szukania uytkownikw, np. \'cn=ldapuser,ou=public,o=org\'';
$string['auth_ldap_bind_pw'] = 'Haso dla funkcji bind-user';
$string['auth_ldap_contexts'] = 'Lista kontekstw, w ktrych znajduj si uytkownicy. Oddzielaj rne konteksty symbolem \';\', np. \'ou=users,o=org; ou=others,o=org\'';
$string['auth_ldap_create_context'] = 'Jeeli wczysz opcj tworzenia uytkownikw z potwierdzeniem poczt elektroniczn, zdefiniuj kontekst, w ktrym tworzeni s tacy uytkownicy. Powinien by rni si od kontekstu innych uytkownikw w celu uniknicia problemw zwizanych z bezpieczestwem. Nie musisz dodawa tego kontekstu do zmiennej ldap_context-variable - Moodle automatycznie wyszuka uytkownikw w tym kontekcie.';
$string['auth_ldap_creators'] = 'Lista grup, ktrych czonkowie mog tworzy nowe kursy. Oddziel kolejne grupy symbolem \';\'. Przykadowa lista: \'cn=teachers,ou=staff,o=myorg\'';
$string['auth_ldap_host_url'] = 'Okrel hosta LDAP za pomoc adresu, np. URL\'ldap://ldap.myorg.com/\' lub \'ldaps://ldap.myorg.com/\'';
$string['auth_ldap_memberattribute'] = 'Okrel atrybut czonkostwa uytkownika jeeli uytkownik naley do grupy. Zazwyczaj jest to \'member\'';
$string['auth_ldap_objectclass'] = 'Filtr wykorzystany do nazywania/szukania uytkownikw. Zwykle bdzie to objectClass=posixAccount. Ustawienie objectClass=* zwrci wszystkie obiekty LDAP.';
$string['auth_ldap_search_sub'] = 'Wpisz warto &lt;&gt; 0 jeeli chcesz szuka uytkownikw z podkontekstw';
$string['auth_ldap_update_userinfo'] = 'Uaktualnij informacje o uytkowniku (imi, nazwisko, adres...) z LDAP do Moodle. Informacje na temat mapowania: /auth/ldap/attr_mappings.php';
$string['auth_ldap_user_attribute'] = 'Atrybut uywany do nazywania/szukania uytkownikw, zwykle \'cn\'.';
$string['auth_ldap_version'] = 'Wersja protokou LDAP uywana przez serwer.';
$string['auth_ldapdescription'] = 'Metoda ta zapewnia uwierzytelnienie wzgldem zewntrznego serwera LDAP.<br> Jeeli podana nazwa uytkownika i haso s poprawne, Moodle dokonuje wpisu nowego uytkownika do swojej bazy danych. Modu ten moe odczytywa atrybuty uytkownika z LDAP i wstpnie wypeni odpowiednie pola w Moodle. Przy kolejnych logowaniach sprawdzane s tylko nazwa uytkownika i haso.';
$string['auth_ldapextrafields'] = 'Te pola s opcjonalne. Moesz wstpnie wypeni niektre pola dotyczce uytkownikw Moodle informacjami z okrelonych tutaj <B>pl LDAP.<B> <P> Jeeli pola te pozostawisz puste, adne informacje nie zostan przeniesione z LDAP i wykorzystane zostan wartoci domylne Moodle. <P> W obu przypadkach, uytkownik bdzie mg dokona edycji tych pl po zalogowaniu.';
$string['auth_ldaptitle'] = 'Uyj serwera LDAP';
$string['auth_manualdescription'] = 'Metoda ta uniemoliwia uytkownikom tworzenie wasnych kont. Wszystkie konta musz by rcznie utworzone przez administratora (Admin User).';
$string['auth_manualtitle'] = 'Tylko konta utworzone rcznie';
$string['auth_multiplehosts'] = 'Mona wskaza wicej komputerw-hostw np. host1.com; host2.com; host3.com';
$string['auth_nntpdescription'] = 'Metoda ta wykorzystuje serwer NNTP w celu sprawdzenia czy podana nazwa uytkownika i haso s poprawne.';
$string['auth_nntphost'] = 'Adres serwera NNTP. Naley stosowa adres IP, a nie nazw DNS.';
$string['auth_nntpport'] = 'Port serwera (najczciej 119)';
$string['auth_nntptitle'] = 'Uyj serwera NNTP';
$string['auth_nonedescription'] = 'Uytkownicy mog si zarejestrowa i niezwocznie utworzy dziaajce konta, bez uwierzytelniania wzgldem zewntrznego serwera i potwierdzenia e-mailem. Korzystaj z tej opcji ostronie pamitajc o moliwych problemach z bezpieczestwem i administracj.';
$string['auth_nonetitle'] = 'Brak uwierzytelniania';
$string['auth_pop3description'] = 'Metoda ta wykorzystuje serwer POP3 w celu sprawdzenia czy podana nazwa uytkownika i haso s poprawne.';
$string['auth_pop3host'] = 'Adres serwera POP3. Naley stosowa adres IP, a nie nazw DNS.';
$string['auth_pop3mailbox'] = 'Nazwa skrzynki pocztowej, z ktr mam prbowa si czy (zwykle INBOX).';
$string['auth_pop3port'] = 'Port serwera (najczciej 110)';
$string['auth_pop3title'] = 'Uyj serwera POP3';
$string['auth_pop3type'] = 'Typ serwera. Jeeli Twj serwer wykorzystuje certyfikaty bezpieczestwa, wybierz pop3cert.';
$string['auth_user_create'] = 'Wcz opcj tworzenia uytkownikw';
$string['auth_user_creation'] = 'Nowi (anonimowi) uytkownicy mog tworzy konta uytkownika uywajc zewntrznego rda uwierzytelniania z potwierdzeniem poczt elektroniczn. Jeeli wczysz t opcj, pamitaj rwnie o skonfigurowaniu zwizanych z moduami opcji tworzenia uytkownikw.';
$string['auth_usernameexists'] = 'Wybrana nazwa uytkownika ju istnieje - prosz wybra inn.';
$string['authenticationoptions'] = 'Opcje uwierzytelniania';
$string['authinstructions'] = 'Moesz tutaj wprowadzi instrukcje dla Twoich uytkownikw dotyczce nazwy uytkownika i hasa, ktrych powinni uywa. Tekst wpisany w tym miejscu pojawi si na stronie logowania. Jeeli nic nie wpiszesz, nie zostan wywietlone adne instrukcje.';
$string['changepassword'] = 'Zmie adres URL hasa';
$string['changepasswordhelp'] = 'Moesz tutaj okreli miejsce, w ktrym Twoi uytkownicy mog odzyska lub zmieni swoja nazw uytkownika/haso, jeeli ich zapomn. Wybranie tej opcji spowoduje wywietlenie przycisku na stronie logowania i stronach uytkownika. Jeeli nic nie wpiszesz, przycisk nie zostanie wywietlony.';
$string['chooseauthmethod'] = 'Wybierz sposb uwierzytelniania';
$string['guestloginbutton'] = 'Przycisk logowania jako go';
$string['instructions'] = 'Instrukcje';
$string['md5'] = 'Kodowanie MD5';
$string['plaintext'] = 'Zwyky tekst';
$string['showguestlogin'] = 'Moesz ukry bd pokaza przycisk logowania jako go';

?>
